@@ -1240,7 +1240,7 @@ class DatastoreAdminClient(metaclass=DatastoreAdminClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "DatastoreAdminClient":
         return self
 
     def __exit__(self, type, value, traceback):
