@@ -1359,7 +1359,7 @@ class DatastoreClient(metaclass=DatastoreClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "DatastoreClient":
         return self
 
     def __exit__(self, type, value, traceback):
